ExportPlugin

Trait ExportPlugin 

pub trait ExportPlugin: Plugin {
    // Required method
    fn render(
        &self,
        entries: &[Entry],
        options: &RenderOptions,
        config: &Config,
    ) -> String;
}
The interface that export format plugins must implement.

Each plugin provides a trigger pattern used to match --output FORMAT values, settings for configuration, and a render method that formats entries into a string.

Required Methods

fn render( &self, entries: &[Entry], options: &RenderOptions, config: &Config, ) -> String

Render the given entries into the plugin’s output format.

Implementors