Plugin

Trait Plugin 

pub trait Plugin {
    // Required methods
    fn name(&self) -> &str;
    fn settings(&self) -> PluginSettings;
}
The base trait for all plugins (export and import).

Provides the common interface needed by Registry to register and resolve plugins by name and trigger pattern.

Required Methods

fn name(&self) -> &str

Return the canonical name of this plugin.

fn settings(&self) -> PluginSettings

Return the plugin’s settings including trigger pattern.

Implementors