pub trait ImportPlugin: Plugin {
// Required method
fn import(&self, path: &Path) -> Result<Vec<Entry>>;
}Expand description
The interface that import format plugins must implement.
Each plugin provides a trigger pattern used to match --type FORMAT values
and an import method that reads entries from a file path.