pub trait ExportPlugin {
// Required methods
fn name(&self) -> &str;
fn render(
&self,
entries: &[Entry],
options: &RenderOptions,
config: &Config,
) -> String;
fn settings(&self) -> ExportPluginSettings;
}Expand description
The interface that export format plugins must implement.
Each plugin provides a trigger pattern used to match --output FORMAT values,
settings for configuration, and a render method that formats entries into a string.
Required Methods
Sourcefn render(
&self,
entries: &[Entry],
options: &RenderOptions,
config: &Config,
) -> String
fn render( &self, entries: &[Entry], options: &RenderOptions, config: &Config, ) -> String
Render the given entries into the plugin’s output format.
Sourcefn settings(&self) -> ExportPluginSettings
fn settings(&self) -> ExportPluginSettings
Return the plugin’s settings including trigger pattern and optional templates.